Re: stripping with an OB callback
| From: | Robert Cummings | Date: | Thu, 21 Sep 2006 00:49:42 +0000 |
| Subject: | Re: stripping with an OB callback | ||
| References: | 1 2 3 | Groups: | php.general |
| Request: | Send a blank email to php-general+get-242004@lists.php.net to get a copy of this message | ||
On Wed, 2006-09-20 at 17:33 -0700, Christopher Watson wrote:
> Hi Robert,
>
> Well, I think the main reason I'm not using transparent output
> compression is because this app shares php.ini with several other PHP
> apps on the server, and I don't want to foist this change on the
> admins of those apps. I was trying to come up with a localized
> strategy for trimming my app's output.
Why settle for 30% speed boost when you can get 90% ...
http://ca3.php.net/manual/en/function.ob-gzhandler.php
:)
Cheers,
Rob.
--
.------------------------------------------------------------.
| InterJinn Application Framework - http://www.interjinn.com
|
:------------------------------------------------------------:
| An application and templating framework for PHP. Boasting |
| a powerful, scalable system for accessing system services |
| such as forms, properties, sessions, and caches. InterJinn |
| also provides an extremely flexible architecture for |
| creating re-usable components quickly and easily. |
`------------------------------------------------------------'